@@ -1,4 +1,5 @@
-import imp
 from .dot import dot
 from .add import add
-from .mul import mul
\ No newline at end of file
+from .mul import mul
+from .sqrt import sqrt
+from .distance import distance
\ No newline at end of file
